@@ -1,10 +1,18 @@
 package FCGI::Client::Record;
-use Any::Moose;
+use strict;
+use warnings;
 use FCGI::Client::Constant;
 use FCGI::Client::RecordHeader;
+use Types::Standard qw/Str/;
 
-has header     => ( is => 'ro', isa => 'FCGI::Client::RecordHeader', handles => [qw/request_id content_length type/] );
-has content    => ( is => 'ro', isa => 'Str' );
+use Moo;
+has header => (
+    is => 'ro',
+    isa => sub { die "header must be FCGI::Client::RecordHeader" unless UNIVERSAL::isa($_[0], 'FCGI::Client::RecordHeader') },
+    handles => [qw/request_id content_length type/]
+);
+has content => ( is => 'ro', isa => Str );
+no Moo;
 
 __PACKAGE__->meta->make_immutable;
 __END__
